# Changelog

## [0.1.91](https://github.com/broadinstitute/genomeshader/compare/v0.1.90...v0.1.91) (2025-12-29)


### Bug Fixes

* refined release process ([430274e](https://github.com/broadinstitute/genomeshader/commit/430274ec45219a6b50903e8ae7dfe2d1acc3549b))
* **ui:** add chromosome bounds checking and fix variant indexing ([98b4de9](https://github.com/broadinstitute/genomeshader/commit/98b4de94d3eb74f174199f2496bdfa2da3c9ed9a))
* **ui:** add chromosome bounds checking and fix variant indexing ([55ee807](https://github.com/broadinstitute/genomeshader/commit/55ee807227940c2b3f3492bb0163d72002c12fd7))

## [0.1.90](https://github.com/broadinstitute/genomeshader/compare/0.1.89...v0.1.90) (2025-12-28)


### Bug Fixes

* configure release-please to use config file and full git history ([46d8e61](https://github.com/broadinstitute/genomeshader/commit/46d8e6122d4113e5be3f890ea42563688efcd5d5))
* configure release-please to use config file and full git history ([c914587](https://github.com/broadinstitute/genomeshader/commit/c914587feeb03f9e9a58234c6c62aeb6b3ffcf37))


### Miscellaneous

* modernize build and release process with release-please ([8500372](https://github.com/broadinstitute/genomeshader/commit/850037284a25e5bb1b11f01fd225603e011a99a6))
* modernize build and release process with release-please ([b9863e8](https://github.com/broadinstitute/genomeshader/commit/b9863e8fd77f00cc9feb0d2fdbea3e1809ee7f30))
